<template>
  <div class="bbsl-common-page">
    <div class="bbsl-btn-content" ref="btnPanel">
      <el-button icon="el-icon-sort" @click="savePropertyf">保存排序号
      </el-button>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <el-table border size="mini" :data="AttributeTableData" :height="tableMaxHeight" :style="{ width: '100%' }"
        :cell-style="{ 'text-align': 'center' }" :header-cell-style="{ 'text-align': 'center' }"
        @row-dblclick="handleDbClick" @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column label="序号" type="index" width="55"></el-table-column>
        <el-table-column  prop="code" label="属性标识"></el-table-column>
        <el-table-column  prop="name" label="属性名称"></el-table-column>
        <el-table-column  prop="typeName" label="属性类型"></el-table-column>
        <el-table-column  prop="dataUnitNane" label="数据单位"></el-table-column>
        <el-table-column  prop="isReadonly" label="是否只读">
          <template slot-scope="scope">
            <div>
              {{ scope.row.isReadonly == 1 ? '是' : '否' }}
            </div>
          </template>
        </el-table-column>
        <el-table-column prop="memo" label="备注"></el-table-column>
        <el-table-column  prop="sn" label="排序" show-overflow-tooltip>
          <template slot-scope="scope">
            <el-input type="number" size="small" min="1" @input="insort(scope.row)" v-model="scope.row.sn">
            </el-input>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background ref="paginationPanel" @size-change="handleSizeChange"
        @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
        :total="total"></el-pagination>
    </div>
    <!-- 属性弹窗 -->
    <EquipAttributeDialog ref="attributemodel" @loadData="loadData" :parameterID="parameterID" :pId="pId">
    </EquipAttributeDialog>
  </div>
</template>
<script>
import PhysicalModel from '@/api/device/PhysicalModel.js'
import EquipAttributeDialog from '@/views/Device/deviceManage/components/modle/EquipAttributeDialog'
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'EquipAttrbuteDefinition',
  props: {
    parameterData: {
      type: Object,
      default: function () {
        return
      }
    }
  },
  components: {
    EquipAttributeDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      pId: '',
      activeName: 'first',
      AttributeTableData: [],
      parameterID: {},
      dataFormarts: [],
      dataTypes: [],
      dataUnits: [],
      sortList: {}
    }
  },
  created() {
    this.parameterID = this.parameterData
    // 数据单位
    this.dataUnits = dictUtils.getDictItemsFromCache('bjdw')
    // 属性类型
    this.dataTypes = dictUtils.getDictItemsFromCache('sxlx')
  },
  methods: {
    // 修改
    handleUpdate(row) {
      // console.log(row.id)
      this.$refs.attributemodel.Update(row)
    },
    loadData(page) {
      console.log(this.parameterData.productId, 'res')
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.queryParam.querys = [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'productId',
          relation: 'AND',
          value: this.parameterData.productId
        }
      ]
      this.queryParam.sorter = [
        {
          direction: 'ASC',
          property: 'sn'
        }
      ]
      this.AttributeTableData = []
      PhysicalModel.attributeList(this.queryParam, res => {
        // console.log(res, 'res')
        this.total = res.total
        res.rows.sort((a, b) => {
          return a.sn - b.sn
        })
        this.AttributeTableData = res.rows
        this.AttributeTableData.forEach(e => {
          this.dataTypes.forEach(t => {
            if (t.value == e.dataType) {
              e.typeName = t.name
            }
          })
          this.dataUnits.forEach(x => {
            if (x.value == e.dataUnit) {
              e.dataUnitNane = x.name
            }
          })
        })
        this.$set(this.AttributeTableData)
      })
    },
    savePropertyf() {
      PhysicalModel.saveAttributeProperty(this.sortList, res => {
        if (res.state) {
          this.$notify({
            type: 'success',
            message: res.message,
            duration: 2000
          })
          this.loadData()
        } else {
          this.$message.warning(res.message)
        }
      })
    },
    insort(val) {
      let id = val.id
      let value = val.sn
      this.sortList[id] = value
    }
  }
}
</script>
<style lang="scss" scoped>
::v-deep .el-table {
  height: 100% !important;
}

::v-deep .bbsl-table-content {
  box-shadow: 0px 0px 0 0;
  margin-top: 0px;
  padding: 0px;
}

.bbsl-common-page {
  height: calc(100% - 10px);
}
</style>
